@@ -4,12 +4,12 @@ import logging
 import click
 from voluptuous import Schema
 from curator import actions
-from curator.config_utils import process_config
+from curator.config_utils import process_config, password_filter
 from curator.defaults import settings
-from curator.exceptions import NoIndices, NoSnapshots
+from curator.exceptions import ClientException, ConfigurationError, NoIndices, NoSnapshots
 from curator.indexlist import IndexList
 from curator.snapshotlist import SnapshotList
-from curator.utils import get_client, get_yaml, prune_nones, validate_actions
+from curator.utils import get_client, get_yaml, prune_nones, validate_actions, get_write_index
 from curator.validators import SchemaCheck
 from curator._version import __version__
 
@@ -22,6 +22,7 @@ CLASS_MAP = {
     'delete_indices' : actions.DeleteIndices,
     'delete_snapshots' : actions.DeleteSnapshots,
     'forcemerge' : actions.ForceMerge,
+    'freeze': actions.Freeze,
     'index_settings' : actions.IndexSettings,
     'open' : actions.Open,
     'reindex' : actions.Reindex,
@@ -30,6 +31,7 @@ CLASS_MAP = {
     'rollover' : actions.Rollover,
     'snapshot' : actions.Snapshot,
     'shrink' : actions.Shrink,
+    'unfreeze' : actions.Unfreeze,
 }
 
 def process_action(client, config, **kwargs):
@@ -73,7 +75,7 @@ def process_action(client, config, **kwargs):
                 'Removing indices from alias "{0}"'.format(opts['name']))
             removes.iterate_filters(config['remove'])
             action_obj.remove(
-                removes, warn_if_no_indices= opts['warn_if_no_indices'])
+                removes, warn_if_no_indices=opts['warn_if_no_indices'])
         if 'add' in config:
             logger.debug('Adding indices to alias "{0}"'.format(opts['name']))
             adds.iterate_filters(config['add'])
@@ -115,10 +117,10 @@ def run(config, action_file, dry_run=False):
     #########################################
     logger.debug('action_file: {0}'.format(action_file))
     action_config = get_yaml(action_file)
-    logger.debug('action_config: {0}'.format(action_config))
+    logger.debug('action_config: {0}'.format(password_filter(action_config)))
     action_dict = validate_actions(action_config)
     actions = action_dict['actions']
-    logger.debug('Full list of actions: {0}'.format(actions))
+    logger.debug('Full list of actions: {0}'.format(password_filter(actions)))
     action_keys = sorted(list(actions.keys()))
     for idx in action_keys:
         action = actions[idx]['action']
@@ -157,8 +159,33 @@ def run(config, action_file, dry_run=False):
         kwargs['dry_run'] = dry_run
 
         # Create a client object for each action...
-        client = get_client(**client_args)
-        logger.debug('client is {0}'.format(type(client)))
+        logger.info('Creating client object and testing connection')
+        try:
+            client = get_client(**client_args)
+        except (ClientException, ConfigurationError):
+            sys.exit(1)
+
+        ### Filter ILM indices unless expressly permitted
+        if allow_ilm:
+            logger.warning('allow_ilm_indices: true')
+            logger.warning('Permitting operation on indices with an ILM policy')
+        if not allow_ilm and action not in settings.snapshot_actions():
+            if actions[idx]['action'] == 'rollover':
+                alias = actions[idx]['options']['name']
+                write_index = get_write_index(client, alias)
+                try:
+                    idx_settings = client.indices.get_settings(index=write_index)
+                    if 'name' in idx_settings[write_index]['settings']['index']['lifecycle']:
+                        logger.info('Alias {0} is associated with ILM policy.'.format(alias))
+                        logger.info(
+                            'Skipping action {0} because allow_ilm_indices is false.'.format(idx))
+                        continue
+                except KeyError:
+                    logger.debug('No ILM policies associated with {0}'.format(alias))
+            elif 'filters' in actions[idx]:
+                actions[idx]['filters'].append({'filtertype': 'ilm'})
+            else:
+                actions[idx]['filters'] = [{'filtertype': 'ilm'}]
         ##########################
         ### Process the action ###
         ##########################
